"""
我们保存接口获取的字段信息，用来比较是否有新增或者减少
"""
PERSONAL_CENTER_MY_DETAIL_FIELDS = {
    'avatar': '头像',
    'certificateValidity': '_certificateValidity',
    'code': '_code',
    'companies': '_companies',  # json
    'companiesCp': '_companiesCp',
    'createUid': '用户创建ID',
    'ctime': '用户创建时间',
    'depts': 'depts',  # json
    'email': '邮箱',
    'enableStatus': '_enableStatus',
    'groupAlias': '_groupAlias',
    'groupName': '_groupName',
    'introduction': '_introduction',
    'lastCommitCertInfoTime': '_lastCommitCertInfoTime',
    'lastLoginTime': '_lastLoginTime',
    'name': '真实姓名',
    'orgCp': '_orgCp',  # json
    'orgId': '_orgId',
    'orgName': '所属部门',
    'orgVo': '_orgVo',  # json
    'passwordComplex': '_passwordComplex',
    'phone': '手机号码',
    'relName': '常用名',
    'roles': '用户角色',  # json
    'sex': '性别',
    'signature': '_signature',
    'sourceType': '_sourceType',
    'type': '_type',
    'updateUid': '更新用户ID',
    'updateUname': '更新用户名字',
    'username': '用户名',
    'utime': '用户更新时间',
    'wxNumber': '微信号',
    # 20250415 删除
    # 'user_id': '用户ID',
    # 20250415 添加
    'id': '用户ID',
    'inviteCode': '_inviteCode',
}

# 供应商结算单详情
SETTLEMENT_INFO_LIST_FIELDS = {
    'attachmentFiles': '附件文件',
    'cname': '创建者',
    'code': '供应商结算单ID',
    'contractCode': '内部合同编号Code',
    'contractId': '内部合同编号ID',
    'contractOfflineCode': '内部合同编号',
    'contractStatus': '内部合同编号状态',
    'cpDisplayName': '所属公司',
    'cpId': '所属公司ID',
    'cpName': '所属公司名字',
    'ctime': '创建时间',
    'endTime': '结束时间',
    'frozenStatus': '冻结状态',
    'id': '结算单ID',
    'isCanApprove': '可以审核',
    'liableManName': '负责人名字',
    'name': '名字',
    'ogTotleAmount': '原始分成总计',
    'settlementCurrency': '结算货币',
    'settlementCurrencyStr': '结算货币名字',
    'spDisplayName': '结算渠道',
    'spId': '结算渠道ID',
    'spName': '结算渠道',
    'startTime': '开始时间',
    'status': '当前状态',
    'statusStr': '当前状态名字',
    'supplierDisplayName': '供应商显示名称',
    'supplierId': '供应商名称ID',
    'supplierName': '供应商名称',
    'totleAmount': '实际分成总计',
    'uname': '操作用户',
    'utime': '操作时间',
    # 后面添加的
    'deDeposit': '_deDeposit',
    'deOtherAmount': '_deOtherAmount',
    'shareProportion': '_shareProportion',
    'exchangeRate': '_exchangeRate',
    'divideType': '_divideType',
    'divisionMethod': '_divisionMethod',
    # 20241101 添加的内容
    'divisionMethodNames': '合作模式名字列表',  # 内容是一个文本列表
    'shareProportions': '分成比例',  # 内容是一个百分比文本列表
    'shareBeginEndTimes': '分成起止时间',  # 内容是一个时间间隔的文本列表
    'copyrightTypeRecord': '_copyrightTypeRecord',
    'copyrightTypeLyric': '_copyrightTypeLyric',
    'copyrightTypeMusic': '_copyrightTypeMusic',
    'copyrightTypeMv': '_copyrightTypeMv',
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'shareBeginDate': '_shareBeginDate',
    'shareEndDate': '_shareEndDate',
    'divisionRuleId': '_divisionRuleId',
    # 2025-04-15 添加
    'preNegativeSettleAmount': '_preNegativeSettleAmount',
    'negativeSettleDeductedAmount': '_negativeSettleDeductedAmount',
    'negativeSettleAmount': '_negativeSettleAmount',
}

# 供应商结算单详情
SETTLEMENT_INFO_FIELDS = {
    'attachmentFiles': '附件文件',
    'cname': '创建者',
    'code': '供应商结算单号',
    'contractCode': '合同Code',
    'contractId': '合同ID',
    'contractOfflineCode': '内部合同编号',
    'contractStatus': '内部合同编号状态',
    'cpDisplayName': '所属公司显示名字',
    'cpId': '所属公司Id',
    'cpName': '所属公司名字',
    'ctime': '创建时间',
    'deDeposit': '扣减保底金',
    'deOtherAmount': '扣减其他费用',
    'divisionMethod': '合作模式Id',
    'endTime': '结算结束时间',
    'frozenStatus': '冻结状态',
    'id': '供应商结算单ID',
    'isCanApprove': '可以审核',
    'liableManName': '合约负责人',
    'name': '名字',
    'ogTotleAmount': '原始分成总计',
    'settlementCurrency': '结算货币ID',
    'settlementCurrencyStr': '结算货币名字',
    'shareProportion': '合同分成比例',
    'spDisplayName': '结算渠道显示名字',
    'spId': '结算渠道Id',
    'spName': '结算渠道名字',
    'startTime': '结算开始时间',
    'status': '当前状态ID',
    'statusStr': '当前状态名字',
    'supplierDisplayName': '供应商显示名字',
    'supplierId': '供应商ID',
    'supplierName': '供应商名字',
    'totleAmount': '实际分成合计',
    'uname': '更新用户',
    'utime': '更新时间',
    # 后面添加的
    'exchangeRate': '_exchangeRate',
    'divideType': '_divideType',
    'currentSettInfo': '_currentSettInfo',
    'innerInfos': '_innerInfos',
    # 20241101 删除的内容
    # 'divisionMethodName': '合作模式名字',
    # 'relationSupplierDocCode': '_relationSupplierDocCode',
    # 'relationSupplierDocId': '_relationSupplierDocId',
    # 'settleFormula': '结算公式',
    # 20241101 添加的内容
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'divisionRuleId': '_divisionRuleId',
    # 2025-04-15 删除
    # 'exchRateDetail': '_exchRateDetail',
    # 2025-04-15 添加
    'preNegativeSettleAmount': '_preNegativeSettleAmount',
    'negativeSettleDeductedAmount': '_negativeSettleDeductedAmount',
    'negativeSettleAmount': '_negativeSettleAmount',

}

# 采购合约列表
CP_CONTRACT_LIST_FIELDS = {
    'attachmentFiles': '附件文件数据',  # 列表数据
    'attachmentType': '附件文件类型',  # 列表
    'authName': '他方签约主体全称',
    'authOrgDisplayName': '他方签约主体显示名称',
    'authOrgId': '他方签约主体',
    'authOrgName': '他方签约主体常用名',
    'authOrgType': '他方签约主体类型',
    'authScope': '_authScope',
    'brandCode': '所属厂牌CODE',
    'brandDisplayName': '所属厂牌显示名称',
    'brandId': '所属厂牌ID',
    'brandName': '所属厂牌全称',
    'cid': '创建者ID',
    'cname': '创建者',
    'code': '合约CODE',
    'companyId': '_companyId',
    'contactsAddress': 'CP联系人地址',
    'contactsEmail': 'CP联系人邮箱',
    'contactsName': 'CP指定联系人',
    'contactsPhone': 'CP联系人电话',
    'contractBeginDate': '合约生效时间',
    'contractEndDate': '合约截止时间',
    'contractProperty': '合约属性',
    'contractPutOffM': '_contractPutOffM',
    'contractPutOffY': '_contractPutOffY',
    'contractStopMode': '_contractStopMode',
    'ctime': '创建时间',
    'dataSourceType': '_dataSourceType',
    'demoCopyrightType': '_demoCopyrightType',  # 列表
    'effectiveRemark': '_effectiveRemark',
    'explain': '合约说明',
    'fileId': '文件ID',
    'id': '合约ID',  # 改为 cp_id
    'identification': '_identification',
    'isCanApprove': '可以审核',
    'liableManEmail': '负责人邮箱',
    'liableManId': '合约负责人ID',
    'liableManName': '合约负责人',
    'liableManPhone': '负责人电话',
    'listStatus': '_listStatus',
    'name': '合约名称',
    'offlineCode': '内部合约编号',
    'orgType': '_orgType',
    'originAuthName': '原始授权方全称',
    'originAuthOrgDisplayName': '原始授权方显示名称',
    'originAuthOrgId': '原始授权方ID',
    'originAuthOrgName': '原始授权方名称',
    'originAuthOrgType': '原始授权方类型',
    'otherAuthOrgs': '其他授权方数据',  # 列表数据
    'ourMainSignOrgId': '_ourMainSignOrgId',
    'ourSignOrgId': '我方签约主体ID',
    'ourSignOrgName': '我方签约主体',
    'outContractNo': '外部合约编号',
    'productActualCount': '实际歌曲数',
    'productCount': '合约歌曲数',
    'relationContractExplain': '_relationContractExplain',
    'relationContractNo': '_relationContractNo',
    'signTime': '合约签署时间',
    'status': '合约状态',
    'type': '合约类型',  # 列表
    'uid': '更新用户ID',
    'uname': '更新用户',
    'utime': '更新时间',
    # 20241101 添加的内容
    'ourSignName': '_ourSignName',
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'cpBeginEndTime': '_cpBeginEndTime',
    'divisionMethodNames': '合作模式名字列表',  # 内容是一个文本列表
    'shareProportions': '分成比例',  # 内容是一个文本列表
    'shareBeginEndTimes': '分成起止时间',  # 内容是一个文本列表
    # 2025-04-15 添加
    'lockStatus': '_lockStatus',
    'minPayAmount': '_minPayAmount',
    'authBeginTime': '_authBeginTime',
    'authEndTime': '_authEndTime',
    'negativeSettleAmount': '_negativeSettleAmount',
}

# 采购合约详情
CP_CONTRACT_FIELDS = {
    'attachmentFiles': '附件文件数据',  # 列表数据
    'attachmentType': '附件文件类型',  # 列表
    'authName': '他方签约主体全称',
    'authOrgDisplayName': '他方签约主体显示名称',
    'authOrgId': '他方签约主体',
    'authOrgName': '他方签约主体常用名',
    'authOrgType': '他方签约主体类型',
    'authScope': '_authScope',
    'brandCode': '所属厂牌CODE',
    'brandDisplayName': '所属厂牌显示名称',
    'brandId': '所属厂牌ID',
    'brandName': '所属厂牌全称',
    'cid': '创建者ID',
    'cname': '创建者',
    'code': '合约CODE',
    'companyId': '_companyId',
    'contactsAddress': 'CP联系人地址',
    'contactsEmail': 'CP联系人邮箱',
    'contactsName': 'CP指定联系人',
    'contactsPhone': 'CP联系人电话',
    'contractBeginDate': '合约生效时间',
    'contractEndDate': '合约截止时间',
    'contractProperty': '合约属性',
    'contractPutOffM': '_contractPutOffM',
    'contractPutOffY': '_contractPutOffY',
    'contractStopMode': '_contractStopMode',
    'ctime': '创建时间',
    'dataSourceType': '_dataSourceType',
    'demoCopyrightType': '_demoCopyrightType',  # 列表
    'effectiveRemark': '_effectiveRemark',
    'explain': '合约说明',
    'fileId': '文件ID',
    'id': '合约ID',  # 改为 cp_id
    'identification': '_identification',
    'isCanApprove': '可以审核',
    'liableManEmail': '负责人邮箱',
    'liableManId': '合约负责人ID',
    'liableManName': '合约负责人',
    'liableManPhone': '负责人电话',
    'listStatus': '_listStatus',
    'name': '合约名称',
    'offlineCode': '内部合约编号',
    'orgType': '_orgType',
    'originAuthName': '原始授权方全称',
    'originAuthOrgDisplayName': '原始授权方显示名称',
    'originAuthOrgId': '原始授权方ID',
    'originAuthOrgName': '原始授权方名称',
    'originAuthOrgType': '原始授权方类型',
    'otherAuthOrgs': '其他授权方数据',  # 列表数据
    'ourMainSignOrgId': '_ourMainSignOrgId',
    'ourSignOrgId': '我方签约主体ID',
    'ourSignOrgName': '我方签约主体',
    'outContractNo': '外部合约编号',
    'productActualCount': '实际歌曲数',
    'productCount': '合约歌曲数',
    'relationContractExplain': '_relationContractExplain',
    'relationContractNo': '_relationContractNo',
    'signTime': '合约签署时间',
    'status': '合约状态',
    'type': '合约类型',  # 列表
    'uid': '更新用户ID',
    'uname': '更新用户',
    'utime': '更新时间',
    # 20241101 添加的内容
    'ourSignName': '_ourSignName',
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'cpBeginEndTime': '_cpBeginEndTime',
    'divisionMethodNames': '合作模式名字列表',  # 内容是一个文本列表
    'shareProportions': '分成比例',  # 内容是一个文本列表
    'shareBeginEndTimes': '分成起止时间',  # 内容是一个文本列表
    # 2025-04-15 添加
    'lockStatus': '_lockStatus',
    'minPayAmount': '_minPayAmount',
    'authBeginTime': '_authBeginTime',
    'authEndTime': '_authEndTime',
    'negativeSettleAmount': '_negativeSettleAmount',
}

# 采购合约-版权信息
CP_CONTRACT_DETAIL_COPYRIGHT_FIELDS = {
    'id': '版权信息ID',
    'relationId': '_relationId',
    'relationType': '_relationType',
    'contractStartDate': '授权开始时间',
    'contractEndDate': '授权结束时间',
    'contractExpireDealType': '_contractExpireDealType',
    'contractExtension': '_contractExtension',
    'authChannelType': '_authChannelType',
    'authRegionType': '_authRegionType',
    'contractAttr': '_contractAttr',
    'generalAgent': '_generalAgent',
    'overseasGeneralAgent': '_overseasGeneralAgent',
    'safeguardLegitimate': '_safeguardLegitimate',
    'allowClip': '_allowClip',
    'allowCover': '_allowCover',
    'coverNeedOwnerAllow': '_coverNeedOwnerAllow',
    'coverStartDate': '_coverStartDate',
    'coverEndDate': '_coverEndDate',
    'contractSource': '_contractSource',
    'contractRemarks': '_contractRemarks',
    'authBeginTime': '_authBeginTime',
    'authEndTime': '_authEndTime',
    'authLeftDays': '_authLeftDays',
    'sublicense': '_sublicense',
    'authRightType': '_authRightType',
    'customAuthRight': '_customAuthRight',
    'contractAttrAddition': '_contractAttrAddition',
    'generalAgentRemark': '_generalAgentRemark',
    'safeguardLegitimateRemark': '_safeguardLegitimateRemark',
    'allowClipRemark': '_allowClipRemark',
    'allowCoverRemark': '_allowCoverRemark',
    'sublicenseRemark': '_sublicenseRemark',
    'adapt': '_adapt',
    'adaptRemark': '_adaptRemark',
    'contractAttrAdditionType': '_contractAttrAdditionType',
    'customContractAttrAddition': '_customContractAttrAddition',
    'contractExtensionYear': '_contractExtensionYear',
    'contractExtensionMonth': '_contractExtensionMonth',
    'copyrightRightsIds': '_copyrightRightsIds',
    'copyrightRightsIdsForFront': '_copyrightRightsIdsForFront',
    'userTypes': '_userTypes',
    'copyrightBusinessIds': '_copyrightBusinessIds',
    'authChannelSpIds': '_authChannelSpIds',
    'authChannels': '_authChannels',
    'authRegionIds': '_authRegionIds',
    'continent': '_continent',
    'authRegions': '_authRegions',
    'assetTypes': '_assetTypes',
    'copyrightInfo': '_copyrightInfo',
}

# 采购合约-结算模式(他返回的数据是一个结算模式的列表)
CP_CONTRACT_DETAIL_SETTLEMENT_MODE_FIELDS = {
    'id': '结算模式ID',
    'contractId': '合同ID',
    'accountType': '账户类型',
    'accountName': '银行账户名',
    'accountNum': '银行账户号码',
    'bankName': '开户行',
    'settlementCycle': '结算周期',
    'settlementCurrency': '结算货币',
    'divisionRuleIds': '合作规则',
    'shareProportion': '分成比例',
    'shareBeginDate': '分成开始时间',
    'shareEndDate': '分成结束时间',
    'spType': '渠道类型',
    'copyrightType': '版权类型',
    'shareReference': '分成参照',
    'divisionMethodName': '合作模式名字',
    'divisionMethodCode': '合作模式CODE',
    'spVos': '_spVos',
    'spNames': '_spNames',
}

# 采购合约关联歌曲
CONTRACT_RELATE_SONG_FIELDS = {
    'advertPublishBeginDate': 'advertPublishBeginDate',
    'advertPublishEndDate': 'advertPublishEndDate',
    'albumCode': 'albumCode',
    'albumCopyrightOrgId': 'albumCopyrightOrgId',
    'albumCopyrightOrgName': 'albumCopyrightOrgName',
    'albumId': '专辑ID',
    'albumName': '专辑名',
    'albumSingers': '专辑演唱者列表',
    'albumStatus': 'albumStatus',
    'arrangers': 'arrangers',
    'artistIdentities': 'artistIdentities',
    'authPercentage': 'authPercentage',
    'awardRecord': 'awardRecord',
    'cd': 'cd',
    'cid': '创建者ID',
    'claimRemark': 'claimRemark',
    'clineOrgId': 'clineOrgId',
    'clineYear': 'clineYear',
    'cname': '创建者',
    'code': '歌曲CODE',
    'collectionName': 'collectionName',
    'collectionTranslatedName': 'collectionTranslatedName',
    'composers': 'composers',
    'copyFromSongId': 'copyFromSongId',
    'copyrightMark': 'copyrightMark',
    'creationBackground': 'creationBackground',
    'ctime': '创建时间',
    'customJson': 'customJson',
    'dataSourceType': 'dataSourceType',
    'dataSourceUk': 'dataSourceUk',
    'firstPublishDate': '期望上线时间',
    'hasPublicity': 'hasPublicity',
    'id': 'id',
    'introduction': 'introduction',
    'isbn': 'isbn',
    'isrc': 'isrc',
    'iswc': 'iswc',
    'langTags': 'langTags',
    'languageTagId': 'languageTagId',
    'liableManId': '合约负责人ID',
    'liableManName': '合约负责人名字',
    'lockStatus': 'lockStatus',
    'lyricCopyrightIds': 'lyricCopyrightIds',
    'lyricists': 'lyricists',
    'mainTune': 'mainTune',
    'movieName': 'movieName',
    'musicCopyrightIds': 'musicCopyrightIds',
    'name': '歌曲名称',
    'originalSingName': 'originalSingName',
    'originalSongName': 'originalSongName',
    'osSongInfo': 'osSongInfo',
    'otherTags': 'otherTags',
    'paymentPattern': 'paymentPattern',
    'plineOrgId': 'plineOrgId',
    'plineYear': 'plineYear',
    'presaleTime': 'presaleTime',
    'productOrgId': 'productOrgId',
    'publicityPaymentPattern': 'publicityPaymentPattern',
    'publishDate': 'publishDate',
    'quality': 'quality',
    'recordArtists': 'recordArtists',
    'recordCopyrightOrgName': '录音版权公司名称',
    'recordOrgId': '录音版权公司ID',
    'remixArtists': 'remixArtists',
    'saleBeginTime': 'saleBeginTime',
    'saleEndTime': 'saleEndTime',
    'salePrice': 'salePrice',
    'selfOwn': 'selfOwn',
    'sendType': 'sendType',
    'singers': '歌曲演唱者列表',
    'songSource': 'songSource',
    'sort': 'sort',
    'soundRecordingCopyrightIds': 'soundRecordingCopyrightIds',
    'source': 'source',
    'status': 'status',
    'styleTagId': 'styleTagId',
    'styleTags': 'styleTags',
    'subtitle': 'subtitle',
    'tmeCmlId': 'TME中央曲库歌曲ID',
    'tmeEpId': 'TME生态歌曲ID',
    'trackNum': 'trackNum',
    'translatedName': 'translatedName',
    'type': 'type',
    'uid': '更新用户ID',
    'uname': '更新用户',
    'uniqueName': 'uniqueName',
    'upCpSongNo': 'upCpSongNo',
    'utime': '更新时间',
    'version': '歌曲版本',
    'versionName': 'versionName',
    'visrc': '虚拟ISRC',
    # 2025-04-15 删除
    # 'distributeFlag': '_distributeFlag',
    # 2025-04-15 添加
    'supplierAuth': '_supplierAuth',
    'channelStatus': '_channelStatus',
    'reason': '_reason',
    'recordCopyrightContracts': '_recordCopyrightContracts',
    'lyricCopyrightContracts': '_lyricCopyrightContracts',
    'musicCopyrightContracts': '_musicCopyrightContracts',
    'authOrgList': '_authOrgList',
    'editLock': '_editLock',
    'editLockOrgName': '_editLockOrgName',
    'remark': '_remark',
    'tmeChannelId': '_tmeChannelId',
    'tmeChannelAlbumId': '_tmeChannelAlbumId',
}

# 售卖合约列表
SP_CONTRACT_LIST_FIELDS = {
    'id': 'id',
    'orgType': '_orgType',
    'name': '合约名称',
    'offlineCode': '内部合约编号',
    'authOrgId': '_authOrgId',
    'type': '_type',
    'code': '合约ID',
    'status': '_status',
    'ctime': '创建时间',
    'cid': '创建者ID',
    'utime': '更新时间',
    'uid': '更新用户ID',
    'fileId': '文件ID',
    'originAuthOrgId': '原始授权方ID',
    'contactsName': 'CP指定联系人',
    'contactsPhone': 'CP联系人电话',
    'contactsEmail': 'CP联系人邮箱',
    'contactsAddress': 'CP联系人地址',
    'explain': '合约说明',
    'signTime': '合约签署时间',
    'contractBeginDate': '合约生效时间',
    'contractEndDate': '授权结束时间',
    'contractStopMode': '_contractStopMode',
    'contractPutOffY': '_contractPutOffY',
    'contractPutOffM': '_contractPutOffM',
    'authScope': '_authScope',
    'demoCopyrightType': '_demoCopyrightType',
    'contractProperty': '合约属性',
    'outContractNo': '外部合约编号',
    'relationContractNo': '_relationContractNo',
    'relationContractExplain': '_relationContractExplain',
    'ourSignOrgId': '我方签约主体ID',
    'productCount': '合约歌曲数',
    'productActualCount': '实际歌曲数',
    'dataSourceType': '_dataSourceType',
    'attachmentType': '附件文件类型',  # 列表
    'liableManId': '负责人ID',
    'ourMainSignOrgId': '_ourMainSignOrgId',
    'liableManPhone': '负责人电话',
    'liableManEmail': '负责人邮箱',
    'liableManName': '合约负责人名字',
    'companyId': '_companyId',
    'effectiveRemark': '_effectiveRemark',
    'identification': '_identification',
    'lockStatus': '_lockStatus',
    'authOrgName': '原始授权方名称',
    'cname': '创建者',
    'uname': '更新用户',
    'fileName': '文件名',
    'ourMainSignOrgName': '_ourMainSignOrgName',
    'ourSignName': '_ourSignName',
    'attachmentFiles': '附件文件数据',
    'brandId': '所属厂牌ID',
    'brandName': '所属厂牌全称',
    'brandDisplayName': '所属厂牌显示名称',
    'brandCode': '所属厂牌CODE',
}

# 售卖合约详情
SP_CONTRACT_FIELDS = {
    'id': 'id',
    'orgType': '_orgType',
    'name': '合约名称',
    'offlineCode': '内部合约编号',
    'authOrgId': '_authOrgId',
    'type': '_type',
    'code': '合约ID',
    'status': '_status',
    'ctime': '创建时间',
    'cid': '创建者ID',
    'utime': '更新时间',
    'uid': '更新用户ID',
    'fileId': '文件ID',
    'originAuthOrgId': '原始授权方ID',
    'contactsName': 'CP指定联系人',
    'contactsPhone': 'CP联系人电话',
    'contactsEmail': 'CP联系人邮箱',
    'contactsAddress': 'CP联系人地址',
    'explain': '合约说明',
    'signTime': '合约签署时间',
    'contractBeginDate': '合约生效时间',
    'contractEndDate': '授权结束时间',
    'contractStopMode': '_contractStopMode',
    'contractPutOffY': '_contractPutOffY',
    'contractPutOffM': '_contractPutOffM',
    'authScope': '_authScope',
    'demoCopyrightType': '_demoCopyrightType',
    'contractProperty': '合约属性',
    'outContractNo': '外部合约编号',
    'relationContractNo': '_relationContractNo',
    'relationContractExplain': '_relationContractExplain',
    'ourSignOrgId': '我方签约主体ID',
    'productCount': '合约歌曲数',
    'productActualCount': '实际歌曲数',
    'dataSourceType': '_dataSourceType',
    'attachmentType': '附件文件类型',  # 列表
    'liableManId': '负责人ID',
    'ourMainSignOrgId': '_ourMainSignOrgId',
    'liableManPhone': '负责人电话',
    'liableManEmail': '负责人邮箱',
    'liableManName': '合约负责人名字',
    'companyId': '_companyId',
    'effectiveRemark': '_effectiveRemark',
    'identification': '_identification',
    'lockStatus': '_lockStatus',
    'authOrgName': '原始授权方名称',
    'cname': '创建者',
    'uname': '更新用户',
    'fileName': '文件名',
    'ourMainSignOrgName': '_ourMainSignOrgName',
    'ourSignName': '_ourSignName',
    'attachmentFiles': '附件文件数据',
    'brandId': '所属厂牌ID',
    'brandName': '所属厂牌全称',
    'brandDisplayName': '所属厂牌显示名称',
    'brandCode': '所属厂牌CODE',
}

# 支付单列表
SETTLEMENT_PAYMENT_DOCUMENT_LIST_FIELDS = {
    'accountName': '收款方名字',
    'accountNum': '收款方银行账号',
    'bankName': '收款方开户行名字',
    'bfDeDepositBalance': '扣减前保底金余额',
    'bfDeOtherAmountBalance': '扣减前其他费用余额',
    'cname': '创建者',
    'code': '支付单CODE',
    'confirmInfo': '_confirmInfo',
    'confirmStatus': '_confirmStatus',
    'contractCode': '内部合同Code',
    'contractId': '内部合同ID',
    'contractName': '内部合同名称',
    'contractOfflineCode': '内部合同编号',
    'contractStatus': '内部合同编号状态',
    'cpDisplayName': '所属公司显示名字',
    'cpId': '所属公司Id',
    'cpName': '所属公司名字',
    'ctime': '创建时间',
    'deDeposit': '扣减保底金',
    'deOtherAmount': '扣减其他费用',
    'divisionMethodName': '合作模式名字',
    'endTime': '结算结束时间',
    'id': '支付单Id',
    'isCanApprove': '可以审核',
    'liableManName': '合约负责人',
    'name': '支付单名称',
    'ogTotleAmount': '原始分成总计',
    'payTotleAmount': '实际分成合计',
    'paymentAttachments': '支付单附件',  # 支付单附件 一个包含字典的列表
    'paymentInvoiceAttachments': '_paymentInvoiceAttachments',
    'paymentReceiptAttachments': '_paymentReceiptAttachments',
    'settleFormula': '结算公式',
    'settlementCurrency': '结算货币ID',
    'settlementCurrencyStr': '结算货币名字',
    'shareAchievedAmount': '_shareAchievedAmount',
    'shareProportion': '合同分成比例',
    'spDisplayName': '结算渠道显示名字',
    'spId': '结算渠道Id',
    'spName': '结算渠道名字',
    'startTime': '结算开始时间',
    'sid': '_sid',
    'sstatus': '_sstatus',
    'shareInterval': '_shareInterval',
    'status': '状态',
    'statusStr': '当前状态名字',
    'supplierDisplayName': '供应商显示名字',
    'supplierId': '供应商ID',
    'supplierName': '供应商名字',
    'totleAmount': '实际分成合计',
    'uname': '更新用户',
    'utime': '更新时间',
    # 20241101 删除的内容
    # 'divisionMethod': '合作模式Id',
    # 20241101 添加的内容
    'divisionRuleId': '_divisionRuleId',
    'divisionModeNames': '_divisionModeNames',  # 内容是一个文本列表
    'shareProportions': '分成比例',  # 内容是一个百分比文本列表
    'bname': '_bname',
    'fname': '_fname',
    'zname': '_zname',
    'copyrightTypeRecord': '_copyrightTypeRecord',
    'copyrightTypeLyric': '_copyrightTypeLyric',
    'copyrightTypeMusic': '_copyrightTypeMusic',
    'copyrightTypeMv': '_copyrightTypeMv',
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'settlePaymentProofGenerationStatus': '_settlePaymentProofGenerationStatus',
    # 20250415 添加
    'preNegativeSettleAmount': '_preNegativeSettleAmount',
    'negativeSettleDeductedAmount': '_negativeSettleDeductedAmount',
}

# 支付单详情
SETTLEMENT_PAYMENT_DOCUMENT_DETAIL_FIELDS = {
    'accountName': '收款方名字',
    'accountNum': '收款方银行账号',
    'bankName': '收款方开户行名字',
    'bfDeDepositBalance': '扣减前保底金余额',
    'bfDeOtherAmountBalance': '扣减前其他费用余额',
    'cname': '创建者',
    'code': '支付单CODE',
    'confirmInfo': '_confirmInfo',
    'confirmStatus': '_confirmStatus',
    'contractCode': '内部合同Code',
    'contractId': '内部合同ID',
    'contractName': '内部合同名称',
    'contractOfflineCode': '内部合同编号',
    'contractStatus': '内部合同编号状态',
    'cpDisplayName': '所属公司显示名字',
    'cpId': '所属公司Id',
    'cpName': '所属公司名字',
    'ctime': '创建时间',
    'deDeposit': '扣减保底金',
    'deOtherAmount': '扣减其他费用',
    'divisionMethodName': '合作模式名字',
    'endTime': '结算结束时间',
    'id': '支付单Id',
    'isCanApprove': '可以审核',
    'liableManName': '合约负责人',
    'name': '支付单名称',
    'ogTotleAmount': '原始分成总计',
    'payTotleAmount': '实际分成合计',
    'paymentAttachments': '支付单附件',  # 支付单附件 一个包含字典的列表
    'paymentInvoiceAttachments': '_paymentInvoiceAttachments',
    'paymentReceiptAttachments': '_paymentReceiptAttachments',
    'settleFormula': '结算公式',
    'settlementCurrency': '结算货币ID',
    'settlementCurrencyStr': '结算货币名字',
    'shareAchievedAmount': '_shareAchievedAmount',
    'shareProportion': '合同分成比例',
    'spDisplayName': '结算渠道显示名字',
    'spId': '结算渠道Id',
    'spName': '结算渠道名字',
    'startTime': '结算开始时间',
    'sid': '_sid',
    'sstatus': '_sstatus',
    'shareInterval': '_shareInterval',
    'status': '状态',
    'statusStr': '当前状态名字',
    'supplierDisplayName': '供应商显示名字',
    'supplierId': '供应商ID',
    'supplierName': '供应商名字',
    'totleAmount': '实际分成合计',
    'uname': '更新用户',
    'utime': '更新时间',
    # 20241101 删除的内容
    # 'divisionMethod': '合作模式Id',
    # 20241101 添加的内容
    'divisionRuleId': '_divisionRuleId',
    'divisionModeNames': '_divisionModeNames',  # 内容是一个文本列表
    'shareProportions': '分成比例',  # 内容是一个百分比文本列表
    'bname': '_bname',
    'fname': '_fname',
    'zname': '_zname',
    'copyrightTypeRecord': '_copyrightTypeRecord',
    'copyrightTypeLyric': '_copyrightTypeLyric',
    'copyrightTypeMusic': '_copyrightTypeMusic',
    'copyrightTypeMv': '_copyrightTypeMv',
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'settlePaymentProofGenerationStatus': '_settlePaymentProofGenerationStatus',
    # 20250415 添加
    'preNegativeSettleAmount': '_preNegativeSettleAmount',
    'negativeSettleDeductedAmount': '_negativeSettleDeductedAmount',
}

# 歌曲列表
SONG_LIST_FIELDS = {
    'advertPublishBeginDate': '_advertPublishBeginDate',
    'advertPublishEndDate': '_advertPublishEndDate',
    'albumCode': '专辑CODE',
    'albumCopyrightOrgId': '专辑版权公司ID',
    'albumCopyrightOrgName': '专辑版权公司名称',
    'albumId': '专辑ID',
    'albumName': '专辑名字',
    'albumSingers': '专辑演唱者列表',  # 列表数据 None
    'albumStatus': '专辑状态',
    'arrangers': '编曲人列表',  # 列表数据
    'artistIdentities': '_artistIdentities',
    'awardRecord': '_awardRecord',
    'cd': 'CD集',
    'channelStatus': '渠道方状态',
    'cid': '创建者ID',
    'claimRemark': '_claimRemark',
    'clineOrgId': '_clineOrgId',
    'clineYear': '专辑CLine年份',
    'cname': '创建者',
    'code': 'CODE',
    'collectionName': '_collectionName',
    'collectionTranslatedName': '_collectionTranslatedName',
    'composers': '曲作者',  # 列表数据
    'copyFromSongId': '_copyFromSongId',
    'copyrightMark': '_copyrightMark',
    'creationBackground': '歌曲创作背景',
    'ctime': '创建时间',
    'customJson': '_customJson',
    'dataSourceType': '_dataSourceType',
    'dataSourceUk': '_dataSourceUk',
    'firstPublishDate': '首次发行时间',
    'hasPublicity': '_hasPublicity',
    'id': '歌曲ID',  # 改为 song_id
    'introduction': '歌曲简介',
    'isbn': 'ISBN',
    'isrc': 'ISRC',
    'iswc': 'ISWC',
    'langTags': '歌曲语言列表',  # 列表数据
    'languageTagId': '歌曲语言ID',
    'liableManId': '负责人ID',
    'liableManName': '负责人名字',
    'lockStatus': '_lockStatus',
    'lyricCopyrightContracts': '_lyricCopyrightContracts',  # 列表数据
    'lyricCopyrightIds': '_lyricCopyrightIds',
    'lyricists': '词作者列表',  # 列表数据
    'mainTune': '_mainTune',
    'movieName': '影视名',
    'musicCopyrightContracts': '_musicCopyrightContracts',  # 列表数据
    'musicCopyrightIds': '_musicCopyrightIds',
    'name': '歌曲名称',
    'originalSingName': '_originalSingName',
    'originalSongName': '_originalSongName',
    'osSongInfo': '_osSongInfo',
    'otherTags': '歌曲标签列表',  # 列表数据
    'paymentPattern': '_paymentPattern',
    'plineOrgId': '_plineOrgId',
    'plineYear': '_plineYear',
    'presaleTime': '_presaleTime',
    'productOrgId': '制作公司ID',
    'publicityPaymentPattern': '_publicityPaymentPattern',
    'publishDate': '期望上线时间',
    'quality': '_quality',
    'reason': '_reason',
    'recordArtists': '_recordArtists',  # 列表数据
    'recordCopyrightContracts': '_recordCopyrightContracts',  # 列表数据
    'recordOrgId': '录音公司ID',
    'remixArtists': '_remixArtists',  # 列表数据
    'saleBeginTime': '销售开始时间',
    'saleEndTime': '销售结束时间',
    'salePrice': '销售价钱',
    'selfOwn': '_selfOwn',
    'sendType': '_sendType',
    'singers': '演唱者列表',  # 列表数据
    'songSource': '歌曲来源',
    'sort': '排序',
    'soundRecordingCopyrightIds': '_soundRecordingCopyrightIds',
    'source': '_source',
    'status': '状态',
    'styleTagId': '歌曲风格ID',
    'styleTags': '歌曲风格列表',  # 列表数据
    'subtitle': '歌曲副标题',
    'tmeCmlId': 'TME中央曲库歌曲ID',
    'tmeEpId': 'TME生态歌曲ID',
    'trackNum': '音轨号',
    'translatedName': '歌曲译名',
    'type': '类型',
    'uid': '更新用户ID',
    'uname': '更新用户',
    'uniqueName': '唯一名称',
    'upCpSongNo': '_upCpSongNo',
    'utime': '更新时间',
    'version': '版本列表',  # 列表
    'versionName': '版本名字',
    'visrc': '虚拟ISRC',
    # 20250415 添加
    'supplierAuth': '_supplierAuth',
    'authOrgList': '_authOrgList',  # 列表数据
    'editLock': '_editLock',
    'editLockOrgName': '_editLockOrgName',
}

# 歌曲详情
SONG_DETAIL_FIELDS = {
    'advertPublishBeginDate': '_advertPublishBeginDate',
    'advertPublishEndDate': '_advertPublishEndDate',
    'albumCode': '专辑CODE',
    'albumCopyrightOrgId': '专辑版权公司ID',
    'albumCopyrightOrgName': '专辑版权公司名称',
    'albumId': '专辑ID',
    'albumName': '专辑名字',
    'albumSingers': '专辑演唱者列表',  # 列表数据
    'albumStatus': '专辑状态',
    'arranger': '编曲',  # 列表数据
    'arrangers': '编曲人列表',  # 列表数据
    'artistIdentities': '_artistIdentities',
    'authRegionIds': '_authRegionIds',
    'awardRecord': '_awardRecord',
    'cd': 'CD集',
    'cdId': 'CD集ID',
    'cdName': 'CD集名字',
    'cdNo': 'CD集号码',
    'channelArtists': '渠道方演唱者列表',  # 列表数据
    'channelIdInfos': '渠道方歌曲信息列表',  # 列表数据
    'channelStatus': '渠道方状态',
    'cid': '创建者ID',
    'claimRemark': '_claimRemark',
    'clineOrgDisplayName': '_clineOrgDisplayName',
    'clineOrgId': '_clineOrgId',
    'clineOrgName': '_clineOrgName',
    'clineOrgStatus': '_clineOrgStatus',
    'clineYear': '专辑CLine年份',
    'cname': '创建者',
    'code': 'CODE',
    'collectionName': '_collectionName',
    'collectionTranslatedName': '_collectionTranslatedName',
    'composer': '曲作者',  # 列表数据
    'composers': '曲作者列表',  # 列表数据
    'copyFromSongId': '_copyFromSongId',
    'copyrightMark': '_copyrightMark',
    'creationBackground': '歌曲创作背景',
    'ctime': '创建时间',
    'customJson': '_customJson',
    'dataSourceType': '_dataSourceType',
    'dataSourceUk': '_dataSourceUk',
    'firstPublishDate': '首次发行时间',
    'hasPublicity': '_hasPublicity',
    'haveAllCopyright': '_haveAllCopyright',
    'id': '歌曲ID',  # 改为 song_id
    'introduction': '歌曲简介',
    'isbn': 'ISBN',
    'isrc': 'ISRC',
    'isrcEditFlag': '_isrcEditFlag',
    'iswc': 'ISWC',
    'langTags': '歌曲语言列表',  # 列表数据
    'languageTagId': '歌曲语言ID',
    'liableManId': '负责人ID',
    'liableManName': '负责人名字',
    'lockStatus': '_lockStatus',
    'lyricCopyrightContracts': '_lyricCopyrightContracts',  # 列表数据
    'lyricCopyrightIds': '_lyricCopyrightIds',
    'lyricist': '词作者',  # 列表数据
    'lyricists': '词作者列表',  # 列表数据
    'lyrics': '歌词',
    'mainTune': '_mainTune',
    'movieName': '影视名',
    'musicCopyrightContracts': '_musicCopyrightContracts',  # 列表数据
    'musicCopyrightIds': '_musicCopyrightIds',
    'name': '歌曲名称',
    'offlineDate': '_offlineDate',
    'onlineDate': '_onlineDate',
    'originalSingName': '_originalSingName',
    'originalSongName': '_originalSongName',
    'osSongInfo': '_osSongInfo',
    'otherTags': '歌曲标签列表',  # 列表数据
    'overseasLyrics': '海外歌词列表',  # 列表数据'
    'paymentPattern': '_paymentPattern',
    'plineOrgDisplayName': '_plineOrgDisplayName',
    'plineOrgId': '_plineOrgId',
    'plineOrgName': '_plineOrgName',
    'plineOrgStatus': '_plineOrgStatus',
    'plineYear': '_plineYear',
    'presaleTime': '_presaleTime',
    'producers': '制作人列表',  # 列表数据
    'productOrgId': '制作公司ID',
    'productOrgName': '制作公司',
    'productOrgStatus': '制作公司状态',
    'publicityPaymentPattern': '_publicityPaymentPattern',
    'publishDate': '期望上线时间',
    'quality': '_quality',
    'reason': '_reason',
    'recordArtists': '_recordArtists',  # 列表数据
    'recordCopyrightContracts': '_recordCopyrightContracts',  # 列表数据
    'recordOrgDisplayName': '录音公司常用名',
    'recordOrgId': '录音公司ID',
    'recordOrgName': '录音公司全称',
    'recordOrgStatus': '录音公司状态',
    'recordingCopyright': '_recordingCopyright',
    'remixArtists': '_remixArtists',  # 列表数据
    'rightPercentage': '_rightPercentage',
    'saleBeginTime': '销售开始时间',
    'saleEndTime': '销售结束时间',
    'salePrice': '销售价钱',
    'selfOwn': '_selfOwn',
    'sendType': '_sendType',
    'singers': '演唱者列表',  # 列表数据
    'songLyricCopyrights': '_songLyricCopyrights',
    'songMaterialVo': '_songMaterialVo',
    'songMusicCopyrights': '_songMusicCopyrights',
    'songProducers': '_songProducers',
    'songSource': '歌曲来源',
    'sort': '排序',
    'soundRecordingCopyrightIds': '_soundRecordingCopyrightIds',
    'source': '_source',
    'speptVos': '渠道列表',  # 列表数据
    'status': '状态',
    'styleTagId': '歌曲风格ID',
    'styleTags': '歌曲风格列表',  # 列表数据
    'subtitle': '歌曲副标题',
    'takeDown': '_takeDown',
    'tmeCmlId': 'TME中央曲库歌曲ID',
    'tmeEpId': 'TME生态歌曲ID',
    'tmeTrackId': 'TME音轨ID',
    'trackNum': '音轨号',
    'translatedName': '歌曲译名',
    'type': '类型',
    'uid': '更新用户ID',
    'uname': '更新用户',
    'uniqueName': '唯一名称',
    'upCpSongNo': '_upCpSongNo',
    'utime': '更新时间',
    'version': '版本列表',  # 列表
    'versionName': '版本名字',
    'visrc': '虚拟ISRC',
    'visrcEditFlag': '_visrcEditFlag',
    # 20250415 添加
    'supplierAuth': '_supplierAuth',
    'authOrgList': '_authOrgList',  # 列表数据
    'editLock': '_editLock',
    'editLockOrgName': '_editLockOrgName',
}

# 专辑列表
ALBUM_LIST_FIELDS = {
    'id': '专辑ID',
    'name': '专辑名称',
    'translatedName': '专辑译名',
    'type': '专辑类型',
    'version': '专辑版本',
    'upc': 'UPC',
    'publishDate': '期望上线时间',
    'firstPublishDate': '首次发行时间',
    'selfOwn': '_selfOwn',
    'copyrightOwnerId': '_copyrightOwnerId',
    'recordCompanyId': '_recordCompanyId',
    'source': '_source',
    'introduction': '_introduction',
    'upAlbumId': '_upAlbumId',
    'upRequireOffDate': '_upRequireOffDate',
    'paymentPattern': '_paymentPattern',
    'abroadDocument': '_abroadDocument',
    'cid': '创建者ID',
    'uid': '更新用户ID',
    'ctime': '创建时间',
    'utime': '更新时间',
    'status': '状态',
    'code': 'CODE',
    'languageTagId': '歌曲语言ID',
    'styleTagId': '歌曲风格ID',
    'uniqueName': '唯一名称',
    'advertPublishBeginDate': '_advertPublishBeginDate',
    'advertPublishEndDate': '_advertPublishEndDate',
    'tmeCmlId': 'TME中央曲库歌曲ID',
    'dataSourceType': '_dataSourceType',
    'albumArea': '_albumArea',
    'versionName': '版本名字',
    'presaleTime': '_presaleTime',
    'saleBeginTime': '销售开始时间',
    'saleEndTime': '销售结束时间',
    'salePrice': '销售价钱',
    'dataSourceUk': '_dataSourceUk',
    'hasPublicity': '_hasPublicity',
    'publicityPaymentPattern': '_publicityPaymentPattern',
    'originalCopyrightOwnerId': '_originalCopyrightOwnerId',
    'isStockAlbum': '_isStockAlbum',
    'tmeEpId': 'TME生态歌曲ID',
    'vupc': '虚拟UPC',
    'supplierAuth': '_supplierAuth',
    'platformType': '_platformType',
    'supplierStatus': '_supplierStatus',
    'supplierOrgId': '_supplierOrgId',
    'albumImages': '_albumImages',
    'albumAbroadImages': '_albumAbroadImages',
    'albumAbroadImage': '_albumAbroadImage',
    'albumImage': '_albumImage',
    'copyrightOwnerName': '_copyrightOwnerName',
    'copyrightOwnerDisplayName': '_copyrightOwnerDisplayName',
    'copyrightOwnerCode': '_copyrightOwnerCode',
    'copyrightOwnerStatus': '_copyrightOwnerStatus',
    'recordCompanyName': '_recordCompanyName',
    'recordCompanyDisplayName': '_recordCompanyDisplayName',
    'recordCompanyStatus': '_recordCompanyStatus',
    'singers': '演唱者列表',
    'lang': '语言列表',
    'style': '风格列表',
    'tags': '_tags',
    'cname': '创建者',
    'uname': '更新用户',
    'auditId': '_auditId',
    'auditStatus': '_auditStatus',
    'auditUtime': '_auditUtime',
    'orgType': '_orgType',
    'orgName': '_orgName',
    'orgDisplayName': '_orgDisplayName',
    'attachmentFiles': '附件文件数据',
    'channelIdInfos': '渠道方歌曲信息列表',
    'originalCopyrightOwnerName': '_originalCopyrightOwnerName',
    'originalCopyrightOwnerDisplayName': '_originalCopyrightOwnerDisplayName',
    'originalCopyrightOwnerStatus': '_originalCopyrightOwnerStatus',
    'songPublishDate': '_songPublishDate',
    'albumSongNum': '_albumSongNum',
    'authOrgList': '_authOrgList',
    'ourSignOrgList': '_ourSignOrgList',
    'sourceType': '_sourceType',
    'editLock': '_editLock',
    'editLockOrgName': '_editLockOrgName',
    'plineDisplayName': '专辑PLine显示名字',
    'plineStatus': '专辑PLine状态',
    'clineDisplayName': '专辑CLine显示名字',
    'clineStatus': '专辑CLine状态',
    'clineName': '专辑CLine公司名字',
    'plineName': '专辑PLine公司名字',
    'lockOrgId': '_lockOrgId',
    'clineYear': '专辑CLine年份',
    'clineOrgId': '专辑CLine公司ID',
    'plineYear': '专辑PLine年份',
    'plineOrgId': '专辑PLine公司ID',
}

# 专辑详情
ALBUM_DETAIL_FIELDS = {
    'id': '专辑ID',
    'name': '专辑名称',
    'translatedName': '专辑译名',
    'type': '专辑类型',
    'version': '专辑版本',
    'upc': 'UPC',
    'publishDate': '期望上线时间',
    'firstPublishDate': '首次发行时间',
    'selfOwn': '_selfOwn',
    'copyrightOwnerId': '_copyrightOwnerId',
    'recordCompanyId': '_recordCompanyId',
    'source': '_source',
    'introduction': '_introduction',
    'upAlbumId': '_upAlbumId',
    'upRequireOffDate': '_upRequireOffDate',
    'paymentPattern': '_paymentPattern',
    'abroadDocument': '_abroadDocument',
    'cid': '创建者ID',
    'uid': '更新用户ID',
    'ctime': '创建时间',
    'utime': '更新时间',
    'status': '状态',
    'code': 'CODE',
    'languageTagId': '歌曲语言ID',
    'styleTagId': '歌曲风格ID',
    'uniqueName': '唯一名称',
    'advertPublishBeginDate': '_advertPublishBeginDate',
    'advertPublishEndDate': '_advertPublishEndDate',
    'tmeCmlId': 'TME中央曲库歌曲ID',
    'dataSourceType': '_dataSourceType',
    'albumArea': '_albumArea',
    'versionName': '版本名字',
    'presaleTime': '_presaleTime',
    'saleBeginTime': '销售开始时间',
    'saleEndTime': '销售结束时间',
    'salePrice': '销售价钱',
    'dataSourceUk': '_dataSourceUk',
    'hasPublicity': '_hasPublicity',
    'publicityPaymentPattern': '_publicityPaymentPattern',
    'originalCopyrightOwnerId': '_originalCopyrightOwnerId',
    'isStockAlbum': '_isStockAlbum',
    'tmeEpId': 'TME生态歌曲ID',
    'vupc': '虚拟UPC',
    'supplierAuth': '_supplierAuth',
    'platformType': '_platformType',
    'supplierStatus': '_supplierStatus',
    'supplierOrgId': '_supplierOrgId',
    'albumImages': '_albumImages',
    'albumAbroadImages': '_albumAbroadImages',
    'albumAbroadImage': '_albumAbroadImage',
    'albumImage': '_albumImage',
    'copyrightOwnerName': '_copyrightOwnerName',
    'copyrightOwnerDisplayName': '_copyrightOwnerDisplayName',
    'copyrightOwnerCode': '_copyrightOwnerCode',
    'copyrightOwnerStatus': '_copyrightOwnerStatus',
    'recordCompanyName': '_recordCompanyName',
    'recordCompanyDisplayName': '_recordCompanyDisplayName',
    'recordCompanyStatus': '_recordCompanyStatus',
    'singers': '演唱者列表',  # 列表数据
    'lang': '语言列表',  # 列表数据
    'style': '风格列表',  # 列表数据
    'tags': '_tags',
    'cname': '创建者',
    'uname': '更新用户',
    'auditId': '_auditId',
    'auditStatus': '_auditStatus',
    'auditUtime': '_auditUtime',
    'orgType': '_orgType',
    'orgName': '_orgName',
    'orgDisplayName': '_orgDisplayName',
    'attachmentFiles': '附件文件数据',  # 列表数据
    'channelIdInfos': '渠道方歌曲信息列表',  # 列表数据
    'originalCopyrightOwnerName': '_originalCopyrightOwnerName',
    'originalCopyrightOwnerDisplayName': '_originalCopyrightOwnerDisplayName',
    'originalCopyrightOwnerStatus': '_originalCopyrightOwnerStatus',
    'songPublishDate': '_songPublishDate',
    'albumSongNum': '_albumSongNum',
    'authOrgList': '_authOrgList',  # 列表数据
    'ourSignOrgList': '_ourSignOrgList',  # 列表数据
    'sourceType': '_sourceType',
    'editLock': '_editLock',
    'editLockOrgName': '_editLockOrgName',
    'upAlbumName': '_upAlbumName',
    'songLyricFileVos': '_songLyricFileVos',
    'confirmParam': '_confirmParam',
    'onlineDate': '_onlineDate',
    'offlineDate': '_offlineDate',
    'authRegionType': '_authRegionType',
    'authRegions': '_authRegions',
    'tmeAlbumId': 'TME专辑ID',
    'odAlbumId': '_odAlbumId',
    'upcEditFlag': '_upcEditFlag',
    'vupcEditFlag': '_vupcEditFlag',
    'speptVos': '_speptVos',
    'plineDisplayName': '专辑PLine显示名字',
    'plineStatus': '专辑PLine状态',
    'clineDisplayName': '专辑CLine显示名字',
    'clineStatus': '专辑CLine状态',
    'clineName': '专辑CLine公司名字',
    'plineName': '专辑PLine公司名字',
    'lockOrgId': '_lockOrgId',
    'clineYear': '专辑CLine年份',
    'clineOrgId': '专辑CLine公司ID',
    'plineYear': '专辑PLine年份',
    'plineOrgId': '专辑PLine公司ID',
}
